@@ -8,6 +8,8 @@ import webbrowser
 
 from functools import wraps, partial
 
+import gobject
+
 from tryton.gui.window.win_search import WinSearch
 from tryton.gui.window.win_form import WinForm
 from tryton.gui.window.view_form.screen import Screen
@@ -171,6 +173,7 @@ class Affix(Cell):
 
 class GenericText(Cell):
     align = 0
+    editable = None
 
     def __init__(self, view, attrs, renderer=None):
         super(GenericText, self).__init__()
@@ -260,6 +263,10 @@ class GenericText(Cell):
             callback()
 
     def editing_started(self, cell, editable, path):
+        def remove(editable):
+            self.editable = None
+        self.editable = editable
+        editable.connect('remove-widget', remove)
         return False
 
     def _get_record_field(self, path):
@@ -422,9 +429,15 @@ class Binary(GenericText):
         if renderer is None:
             renderer = partial(CellRendererBinary, bool(self.filename))
         super(Binary, self).__init__(view, attrs, renderer=renderer)
-        self.renderer.connect('select', self.select_binary)
-        self.renderer.connect('open', self.open_binary)
-        self.renderer.connect('save', self.save_binary)
+        self.renderer.connect(
+            'select',
+            lambda *args: gobject.idle_add(self.select_binary, *args))
+        self.renderer.connect(
+            'open',
+            lambda *args: gobject.idle_add(self.open_binary, *args))
+        self.renderer.connect(
+            'save',
+            lambda *args: gobject.idle_add(self.save_binary, *args))
         self.renderer.connect('clear', self.clear_binary)
 
     def get_textual_value(self, record):
